=========================
 ``zope.viewlet`` README
=========================

.. image:: https://img.shields.io/pypi/v/zope.viewlet.svg
        :target: https://pypi.python.org/pypi/zope.viewlet/
        :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/zope.viewlet.svg
        :target: https://pypi.org/project/zope.viewlet/
        :alt: Supported Python versions

.. image:: https://travis-ci.org/zopefoundation/zope.viewlet.png?branch=master
        :target: https://travis-ci.org/zopefoundation/zope.viewlet

.. image:: https://coveralls.io/repos/github/zopefoundation/zope.viewlet/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/zope.viewlet?branch=master


Viewlets provide a generic framework for building pluggable user interfaces.
